@@ -1,5 +1,3 @@
-from typing import Union
-
 import requests
 from tako.types.common.errors import (
     APIErrorType,
@@ -9,64 +7,79 @@ from tako.types.common.errors import (
     PaymentRequiredError,
     AuthenticationError,
     BadRequestError,
-    InternalServerError
+    InternalServerError,
 )
 
-class RelevantResultsNotFoundException(Exception):
+
+class APIException(Exception):
+    def __init__(self, error: BaseAPIError):
+        self.error = error
+
+    def __str__(self):
+        return self.error.error_message
+
+
+class RelevantResultsNotFoundException(APIException):
     def __init__(self, error: RelevantResultsNotFoundError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
-    
-class RateLimitExceededException(Exception):
+
+
+class RateLimitExceededException(APIException):
     def __init__(self, error: RateLimitExceededError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
 
-class PaymentRequiredException(Exception):
+
+class PaymentRequiredException(APIException):
     def __init__(self, error: PaymentRequiredError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
 
-class AuthenticationErrorException(Exception):
+
+class AuthenticationErrorException(APIException):
     def __init__(self, error: AuthenticationError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
 
-class BadRequestException(Exception):
+
+class BadRequestException(APIException):
     def __init__(self, error: BadRequestError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
 
-class InternalServerErrorException(Exception):
+
+class InternalServerErrorException(APIException):
     def __init__(self, error: InternalServerError):
         self.error = error
 
     def __str__(self):
         return self.error.error_message
-    
 
-APIException = Union[PaymentRequiredException, RateLimitExceededException, RelevantResultsNotFoundException, InternalServerErrorException, AuthenticationErrorException, BadRequestException]
 
 def raise_exception_from_response(response: requests.Response):
     if response.status_code == 401:
         raise AuthenticationErrorException(
             AuthenticationError(
                 error_type=APIErrorType.AUTHENTICATION_ERROR,
-                error_message="Invalid API key"
+                error_message="Invalid API key",
             )
         )
     elif response.status_code != 200:
-        raise_exception_from_error(BaseAPIError.model_validate(response.json()))
+        try:
+            raise_exception_from_error(BaseAPIError.model_validate(response.json()))
+        except Exception:
+            pass
     return
 
 
@@ -90,4 +103,3 @@ def raise_exception_from_error(error: BaseAPIError):
         raise BadRequestException(error)
     else:
         raise ValueError(f"Unknown error type: {error.error_type}")
-
